## Update Facts

We have finished working on the following hypothesis:

{current_hypothesis}

In completing our work, we may have learned something new. Please rewrite the following fact sheet, updating it to include anything new we have learned that may be helpful. Updates may be made to any section of the fact sheet.

Here is the old fact sheet:

{fact_sheet}

